define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"months-standAlone-abbr@localeAlias407": {
		"bundle": "ethiopic",
		"target": "months-format-abbr"
	},
	"timeFormat@localeAlias438": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"months-standAlone-abbr@localeAlias408": {
		"bundle": "ethiopic",
		"target": "months-format-wide"
	},
	"field-sun-narrow-relative+0": "this Sunday",
	"field-sun-narrow-relative+1": "next Sunday",
	"months-format-wide": [
		"Meskerem",
		"Tekemt",
		"Hedar",
		"Tahsas",
		"Ter",
		"Yekatit",
		"Megabit",
		"Miazia",
		"Genbot",
		"Sene",
		"Hamle",
		"Nehasse",
		"Pagumen"
	],
	"field-zone-short@localeAlias503": {
		"bundle": "",
		"target": "field-zone"
	},
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"eraNarrow": [
		"ERA0",
		"ERA1"
	],
	"field-fri-narrow-relative+1": "next Friday",
	"dayPeriods-standAlone-abbr@localeAlias430": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"quarters-standAlone-wide@localeAlias426": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateTime@localeAlias439": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"days-standAlone-wide@localeAlias420": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-Ehm": "E h:mm a",
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-tue-narrow@localeAlias477": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"field-tue-narrow@localeAlias478": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-minute-narrow-relative+0": "this minute",
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-wed-short@localeAlias479": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-thu-relative+0": "this Thursday",
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"field-hour-relative+0": "this hour",
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"quarters-format-narrow@localeAlias423": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"field-minute-narrow": "Minute",
	"field-year-narrow@localeAlias444": {
		"bundle": "",
		"target": "field-year-short"
	},
	"field-year-narrow@localeAlias445": {
		"bundle": "",
		"target": "field-year"
	},
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"days-standAlone-short@localeAlias417": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"field-era-short": "Era",
	"field-hour-short@localeAlias494": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-day-narrow-relative+1": "tomorrow",
	"days-standAlone-short@localeAlias418": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-short@localeAlias419": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-month": "Month",
	"field-month-narrow@localeAlias450": {
		"bundle": "",
		"target": "field-month-short"
	},
	"months-standAlone-wide": [
		"Meskerem",
		"Tekemt",
		"Hedar",
		"Tahsas",
		"Ter",
		"Yekatit",
		"Megabit",
		"Miazia",
		"Genbot",
		"Sene",
		"Hamle",
		"Nehasse",
		"Pagumen"
	],
	"field-month-narrow@localeAlias451": {
		"bundle": "",
		"target": "field-month"
	},
	"field-weekOfMonth-short@localeAlias455": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-sat-short@localeAlias488": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"months-standAlone-wide@localeAlias409": {
		"bundle": "ethiopic",
		"target": "months-format-wide"
	},
	"field-year-narrow": "Year",
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"days-format-abbr@localeAlias411": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-day-short@localeAlias458": {
		"bundle": "",
		"target": "field-day"
	},
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"field-month-short@localeAlias449": {
		"bundle": "",
		"target": "field-month"
	},
	"field-wed-short-relative+0": "this Wednesday",
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"months-format-abbr@localeAlias405": {
		"bundle": "ethiopic",
		"target": "months-format-wide"
	},
	"field-quarter-short-relative+-1": "last quarter",
	"field-year-short-relative+-1": "last year",
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-weekOfMonth-narrow": "Week Of Month",
	"days-format-narrow@localeAlias412": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"dateFormatItem-y": "G y",
	"field-dayOfYear-narrow@localeAlias462": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-weekday-short@localeAlias464": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-dayOfYear-narrow@localeAlias463": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"field-mon-narrow@localeAlias474": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"field-mon-narrow@localeAlias475": {
		"bundle": "",
		"target": "field-mon"
	},
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"field-sat-relative+-1": "last Saturday",
	"field-sun-narrow@localeAlias471": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-sun-narrow@localeAlias472": {
		"bundle": "",
		"target": "field-sun"
	},
	"dayPeriods@localeAlias427": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "GGGGG y-MM-dd",
	"eraNames": [
		"ERA0",
		"ERA1"
	],
	"field-second-short": "Second",
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"eraAbbr": [
		"ERA0",
		"ERA1"
	],
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-weekday-narrow@localeAlias465": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-weekday-narrow@localeAlias466": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "G y MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"field-week-narrow@localeAlias453": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-week-narrow@localeAlias454": {
		"bundle": "",
		"target": "field-week"
	},
	"field-era-narrow@localeAlias441": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-era-narrow@localeAlias442": {
		"bundle": "",
		"target": "field-era"
	},
	"months-format-narrow@localeAlias406": {
		"bundle": "ethiopic",
		"target": "months-standAlone-narrow"
	},
	"field-second-relative+0": "now",
	"field-quarter-relative+-1": "last quarter",
	"field-fri-short@localeAlias485": {
		"bundle": "",
		"target": "field-fri"
	},
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-hour-narrow@localeAlias495": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"field-hour-narrow@localeAlias496": {
		"bundle": "",
		"target": "field-hour"
	},
	"eraNarrow@localeAlias436": {
		"bundle": "ethiopic",
		"target": "eraAbbr"
	},
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"quarters-standAlone-abbr@localeAlias424": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"quarters-standAlone-abbr@localeAlias425": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-thu-narrow@localeAlias483": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-weekOfMonth-narrow@localeAlias456": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-thu-narrow@localeAlias484": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-weekOfMonth-narrow@localeAlias457": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-year": "Year",
	"field-era": "Era",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-dayperiod-narrow@localeAlias492": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-dayperiod-narrow@localeAlias493": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"field-day-short-relative+-1": "yesterday",
	"dayPeriods-standAlone-wide@localeAlias433": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dateFormatItem-GyMMM": "G y MMM",
	"dayPeriods-standAlone-wide@localeAlias434": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"timeFormat-full": "HH:mm:ss zzzz",
	"days@localeAlias410": {
		"bundle": "gregorian",
		"target": "days"
	},
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "Hour",
	"field-dayperiod-short@localeAlias491": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"field-dayOfYear-narrow": "Day Of Year",
	"field-second-narrow-relative+0": "now",
	"field-week-short@localeAlias452": {
		"bundle": "",
		"target": "field-week"
	},
	"field-quarter": "Quarter",
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"dateFormatItem-yyyy": "G y",
	"field-fri-narrow@localeAlias486": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-fri-narrow@localeAlias487": {
		"bundle": "",
		"target": "field-fri"
	},
	"quarters-format-abbr@localeAlias422": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-mon-relative+-1": "last Monday",
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "G y MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"field-month-short": "Month",
	"dateFormat@localeAlias437": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"field-minute-narrow@localeAlias498": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"field-minute-narrow@localeAlias499": {
		"bundle": "",
		"target": "field-minute"
	},
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"Meskerem",
		"Tekemt",
		"Hedar",
		"Tahsas",
		"Ter",
		"Yekatit",
		"Megabit",
		"Miazia",
		"Genbot",
		"Sene",
		"Hamle",
		"Nehasse",
		"Pagumen"
	],
	"field-quarter-short@localeAlias446": {
		"bundle": "",
		"target": "field-quarter"
	},
	"dayPeriods-format-abbr-am": "AM",
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-sun-short@localeAlias470": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-week-short-relative+1": "next week",
	"dayPeriods-format-wide@localeAlias429": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"field-month-narrow-relative+-1": "last month",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-weekday-short": "Day of the Week",
	"field-day-narrow-relative+-1": "yesterday",
	"field-quarter-narrow@localeAlias447": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"field-quarter-narrow@localeAlias448": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12",
		"13"
	],
	"field-dayOfYear-short@localeAlias461": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "Quarter",
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"field-dayperiod-short": "Dayperiod",
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"dateFormatItem-Ed": "d, E",
	"field-weekdayOfMonth-narrow@localeAlias468": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-weekdayOfMonth-narrow@localeAlias469": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"days-standAlone-abbr@localeAlias415": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-abbr@localeAlias416": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-weekdayOfMonth-short@localeAlias467": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-fri-relative+-1": "last Friday",
	"field-tue-short@localeAlias476": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-wed-narrow@localeAlias480": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-wed-narrow@localeAlias481": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-thu-short@localeAlias482": {
		"bundle": "",
		"target": "field-thu"
	},
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-narrow@localeAlias459": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"field-minute-short@localeAlias497": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-hour-short": "Hour",
	"months-standAlone-abbr": [
		"Meskerem",
		"Tekemt",
		"Hedar",
		"Tahsas",
		"Ter",
		"Yekatit",
		"Megabit",
		"Miazia",
		"Genbot",
		"Sene",
		"Hamle",
		"Nehasse",
		"Pagumen"
	],
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "G y MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-era-narrow": "Era",
	"field-sat-short-relative+-1": "last Saturday",
	"quarters@localeAlias421": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"field-week-short-relative+-1": "last week",
	"field-day-narrow@localeAlias460": {
		"bundle": "",
		"target": "field-day"
	},
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"dayPeriods-standAlone-narrow@localeAlias431": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias432": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-year-narrow-relative+0": "this year",
	"field-year-narrow-relative+1": "next year",
	"field-sat-narrow@localeAlias489": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"dateFormatItem-Gy": "G y",
	"field-zone-narrow": "Zone",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-minute-short": "Minute",
	"eraNames@localeAlias435": {
		"bundle": "ethiopic",
		"target": "eraAbbr"
	},
	"days-format-short@localeAlias413": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-sat-narrow@localeAlias490": {
		"bundle": "",
		"target": "field-sat"
	},
	"days-format-short@localeAlias414": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-Hm": "HH:mm",
	"field-second-short@localeAlias500": {
		"bundle": "",
		"target": "field-second"
	},
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"field-zone-narrow@localeAlias504": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-zone-narrow@localeAlias505": {
		"bundle": "",
		"target": "field-zone"
	},
	"dayPeriods-format-narrow@localeAlias428": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-second-narrow@localeAlias501": {
		"bundle": "",
		"target": "field-second-short"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"field-second-narrow@localeAlias502": {
		"bundle": "",
		"target": "field-second"
	},
	"field-year-short@localeAlias443": {
		"bundle": "",
		"target": "field-year"
	},
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-mon-short@localeAlias473": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-month-short-relative+-1": "last month",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"dateFormatItem-MMMMd": "MMMM d",
	"field-era-short@localeAlias440": {
		"bundle": "",
		"target": "field-era"
	},
	"field-week": "Week",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour"
}
//end v1.x content
,
	"ar": true,
	"cs": true,
	"da": true,
	"de": true,
	"el": true,
	"es": true,
	"fi": true,
	"fr": true,
	"he": true,
	"hr": true,
	"hu": true,
	"ja": true,
	"ko": true,
	"mk": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"ro": true,
	"ru": true,
	"sk": true,
	"sr": true,
	"sv": true,
	"th": true,
	"tr": true,
	"zh": true,
	"zh-hant": true
});